@@ -1,7 +1,10 @@
+from pathlib import Path
 import os
 import sys
 
 import click
+
+from ploomber.spec import DAGSpec
 from ploomber import __version__
 from ploomber import cli as cli_module
 from ploomber import scaffold as _scaffold
@@ -27,16 +30,49 @@ def cli():
     is_flag=True,
     help='Use package template (setup.py)',
 )
-def scaffold(conda, package):
-    """Create new projects and add template tasks
+@click.option(
+    '--empty',
+    is_flag=True,
+    help='Create a sample pipeline.yaml with no tasks',
+)
+@click.option(
+    '--entry-point',
+    '-e',
+    default=None,
+    help='Entry point to add tasks. Invalid if other flags present',
+)
+def scaffold(conda, package, entry_point, empty):
+    """Create new projects (if no pipeline.yaml exists) or add missings tasks
     """
-    loaded = _scaffold.load_dag()
+    template = '-e/--entry-point is not compatible with the {flag} flag'
+
+    if entry_point and conda:
+        raise click.ClickException(template.format(flag='--conda'))
+
+    if entry_point and package:
+        raise click.ClickException(template.format(flag='--package'))
+
+    if entry_point and empty:
+        raise click.ClickException(template.format(flag='--empty'))
+
+    # try to load a dag by looking in default places
+    if not entry_point:
+        loaded = _scaffold.load_dag()
+    else:
+        try:
+            loaded = DAGSpec(entry_point, lazy_import=True), Path(entry_point)
+        except Exception as e:
+            raise click.ClickException(e) from e
 
     if loaded:
+        # add scaffold tasks
         spec, path_to_spec = loaded
         _scaffold.add(spec, path_to_spec)
     else:
-        scaffold_project.cli(project_path=None, conda=conda, package=package)
+        scaffold_project.cli(project_path=None,
+                             conda=conda,
+                             package=package,
+                             empty=empty)
 
 
 @cli.command()
