@@ -201,6 +201,8 @@ class DAGSpec(MutableMapping):
 
     def _init(self, data, env, lazy_import, reload, parent_path,
               look_up_project_root_recursively):
+        self._lazy_import = lazy_import
+
         # initialized with a path to a yaml file...
         if isinstance(data, (str, Path)):
             # TODO: test this
@@ -442,14 +444,19 @@ class DAGSpec(MutableMapping):
 
         if clients:
             for class_name, dotted_path_spec in clients.items():
-                dag.clients[class_name] = dotted_path.call_spec(
-                    dotted_path_spec)
+                dps = dotted_path.DottedPathSpec(dotted_path_spec)
+
+                if self._lazy_import:
+                    dag.clients[class_name] = dps
+                else:
+                    dag.clients[class_name] = dps()
 
-        # FIXME: this violates lazy_import, we must change DAG's implementation
-        # to accept strings as attribute and load them until they are called
         for attr in ['serializer', 'unserializer']:
             if attr in self:
-                setattr(dag, attr, dotted_path.load_dotted_path(self[attr]))
+                setattr(
+                    dag, attr,
+                    dotted_path.DottedPath(self[attr],
+                                           lazy_load=self._lazy_import))
 
         process_tasks(dag, self, root_path=self._parent_path)
 
@@ -472,8 +479,8 @@ class DAGSpec(MutableMapping):
         is used for loading the DAG and submitting tasks and as an argument
         in "ploomber task --entry-point {relative-path}" when executing tasks
         """
-        path = default.entry_point_relative(name=name)
-        return cls(path)
+        relative_path = default.entry_point_relative(name=name)
+        return cls(relative_path), relative_path
 
     @classmethod
     def find(cls,
@@ -593,6 +600,8 @@ class DAGSpecPartial(DAGSpec):
         meta = {'extract_product': False, 'extract_upstream': False}
         data = {'tasks': tasks, 'meta': meta}
 
+        env = env or default.path_to_env_from_spec(path_to_partial)
+
         self._init(data=data,
                    env=env,
                    lazy_import=False,
