@@ -32,7 +32,7 @@ except ImportError:
 
 from ploomber.exceptions import TaskBuildError
 from ploomber.sources import NotebookSource
-from ploomber.sources.NotebookSource import _cleanup_rendered_nb
+from ploomber.sources.notebooksource import _cleanup_rendered_nb
 from ploomber.products import File, MetaProduct
 from ploomber.tasks.abc import Task
 from ploomber.util import requires, chdir_code
